"use client";
import { useCallback } from 'react';
import { useReCaptchaContext } from './ReCaptchaProvider.js';
import { useGrecaptcha, getGrecaptcha } from './utils.js';

/**
 * Custom hook to use Google reCAPTCHA v3.
 *
 * @param [reCaptchaKey] - Optional reCAPTCHA site key. If not provided, it will use the key from the context.
 * @returns An object containing the reCAPTCHA context, grecaptcha instance, reCaptchaKey, and executeRecaptcha function.
 *
 * @example
 * const { executeRecaptcha } = useReCaptcha();
 *
 * const handleSubmit = async () => {
 *   try {
 *     const token = await executeRecaptcha('your_action');
 *     // Use the token for verification
 *   } catch (error) {
 *     console.error('ReCAPTCHA error:', error);
 *   }
 * };
 */
const useReCaptcha = (reCaptchaKey) => {
    const context = useReCaptchaContext();
    const { useEnterprise } = context;
    const grecaptcha = useGrecaptcha(useEnterprise);
    const siteKey = reCaptchaKey || context.reCaptchaKey;
    const executeRecaptcha = useCallback(async (action) => {
        if (!siteKey) {
            throw new Error("ReCaptcha sitekey is not defined");
        }
        const grecaptcha = getGrecaptcha(useEnterprise);
        if (typeof grecaptcha?.execute !== "function") {
            throw new Error("Recaptcha has not been loaded");
        }
        if (typeof grecaptcha.ready === "function") {
            await new Promise((resolve) => {
                grecaptcha.ready(resolve);
            });
        }
        const result = await grecaptcha.execute(siteKey, { action });
        return result;
    }, [useEnterprise, siteKey]);
    return {
        ...context,
        grecaptcha,
        reCaptchaKey: siteKey,
        executeRecaptcha,
    };
};

export { useReCaptcha };
